# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vm_errors.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='vm_errors.proto',
  package='types',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0fvm_errors.proto\x12\x05types\"R\n\x12VMValidationStatus\x12+\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x1d.types.VMValidationStatusCode\x12\x0f\n\x07message\x18\x02 \x01(\t\"L\n\x18VMVerificationStatusList\x12\x30\n\x0bstatus_list\x18\x01 \x03(\x0b\x32\x1b.types.VMVerificationStatus\"\xd2\x01\n\x14VMVerificationStatus\x12;\n\x0bstatus_kind\x18\x01 \x01(\x0e\x32&.types.VMVerificationStatus.StatusKind\x12\x12\n\nmodule_idx\x18\x02 \x01(\r\x12\x32\n\nerror_kind\x18\x03 \x01(\x0e\x32\x1e.types.VMVerificationErrorKind\x12\x0f\n\x07message\x18\x04 \x01(\t\"$\n\nStatusKind\x12\n\n\x06SCRIPT\x10\x00\x12\n\n\x06MODULE\x10\x01\"0\n\x10\x41ssertionFailure\x12\x1c\n\x14\x61ssertion_error_code\x18\x01 \x01(\x04\"\xb5\x01\n\x0f\x41rithmeticError\x12>\n\nerror_code\x18\x01 \x01(\x0e\x32*.types.ArithmeticError.ArithmeticErrorType\"b\n\x13\x41rithmeticErrorType\x12\x1a\n\x16UnknownArithmeticError\x10\x00\x12\r\n\tUnderflow\x10\x01\x12\x0c\n\x08Overflow\x10\x02\x12\x12\n\x0e\x44ivisionByZero\x10\x03\"\x8f\x02\n\x15\x44ynamicReferenceError\x12J\n\nerror_code\x18\x01 \x01(\x0e\x32\x36.types.DynamicReferenceError.DynamicReferenceErrorType\"\xa9\x01\n\x19\x44ynamicReferenceErrorType\x12 \n\x1cUnknownDynamicReferenceError\x10\x00\x12\x1a\n\x16MoveOfBorrowedResource\x10\x01\x12\x1c\n\x18GlobalRefAlreadyReleased\x10\x02\x12\x15\n\x11MissingReleaseRef\x10\x03\x12\x19\n\x15GlobalAlreadyBorrowed\x10\x04\"\xf8\x01\n\x0f\x45xecutionStatus\x12.\n\x0eruntime_status\x18\x01 \x01(\x0e\x32\x14.types.RuntimeStatusH\x00\x12\x34\n\x11\x61ssertion_failure\x18\x02 \x01(\x0b\x32\x17.types.AssertionFailureH\x00\x12\x32\n\x10\x61rithmetic_error\x18\x03 \x01(\x0b\x32\x16.types.ArithmeticErrorH\x00\x12\x37\n\x0freference_error\x18\x04 \x01(\x0b\x32\x1c.types.DynamicReferenceErrorH\x00\x42\x12\n\x10\x65xecution_status\"\x9f\x02\n\x08VMStatus\x12/\n\nvalidation\x18\x01 \x01(\x0b\x32\x19.types.VMValidationStatusH\x00\x12\x37\n\x0cverification\x18\x02 \x01(\x0b\x32\x1f.types.VMVerificationStatusListH\x00\x12?\n\x13invariant_violation\x18\x03 \x01(\x0e\x32 .types.VMInvariantViolationErrorH\x00\x12-\n\x0f\x64\x65serialization\x18\x04 \x01(\x0e\x32\x12.types.BinaryErrorH\x00\x12+\n\texecution\x18\x05 \x01(\x0b\x32\x16.types.ExecutionStatusH\x00\x42\x0c\n\nerror_type*\xf8\x03\n\x16VMValidationStatusCode\x12\x1b\n\x17UnknownValidationStatus\x10\x00\x12\x14\n\x10InvalidSignature\x10\x01\x12\x12\n\x0eInvalidAuthKey\x10\x02\x12\x18\n\x14SequenceNumberTooOld\x10\x03\x12\x18\n\x14SequenceNumberTooNew\x10\x04\x12(\n$InsufficientBalanceForTransactionFee\x10\x05\x12\x16\n\x12TransactionExpired\x10\x06\x12\x1e\n\x1aSendingAccountDoesNotExist\x10\x07\x12\x14\n\x10RejectedWriteSet\x10\x08\x12\x13\n\x0fInvalidWriteSet\x10\t\x12\x1e\n\x1a\x45xceededMaxTransactionSize\x10\n\x12\x11\n\rUnknownScript\x10\x0b\x12\x11\n\rUnknownModule\x10\x0c\x12&\n\"MaxGasUnitsExceedsMaxGasUnitsBound\x10\r\x12*\n&MaxGasUnitsBelowMinTransactionGasUnits\x10\x0e\x12\x1d\n\x19GasUnitPriceBelowMinBound\x10\x0f\x12\x1d\n\x19GasUnitPriceAboveMaxBound\x10\x10*\xc6\x0f\n\x17VMVerificationErrorKind\x12\x1c\n\x18UnknownVerificationError\x10\x00\x12\x14\n\x10IndexOutOfBounds\x10\x01\x12\x14\n\x10RangeOutOfBounds\x10\x02\x12\x19\n\x15InvalidSignatureToken\x10\x03\x12\x1c\n\x18InvalidFieldDefReference\x10\x04\x12\x1d\n\x19RecursiveStructDefinition\x10\x05\x12\x18\n\x14InvalidResourceField\x10\x06\x12\x16\n\x12InvalidFallThrough\x10\x07\x12\x0f\n\x0bJoinFailure\x10\x08\x12 \n\x1cNegativeStackSizeWithinBlock\x10\t\x12\x13\n\x0fUnbalancedStack\x10\n\x12 \n\x1cInvalidMainFunctionSignature\x10\x0b\x12\x14\n\x10\x44uplicateElement\x10\x0c\x12\x17\n\x13InvalidModuleHandle\x10\r\x12\x17\n\x13UnimplementedHandle\x10\x0e\x12\x16\n\x12InconsistentFields\x10\x0f\x12\x10\n\x0cUnusedFields\x10\x10\x12\x10\n\x0cLookupFailed\x10\x11\x12\x16\n\x12VisibilityMismatch\x10\x12\x12\x19\n\x15TypeResolutionFailure\x10\x13\x12\x10\n\x0cTypeMismatch\x10\x14\x12\x15\n\x11MissingDependency\x10\x15\x12\x15\n\x11PopReferenceError\x10\x16\x12\x14\n\x10PopResourceError\x10\x17\x12\x1f\n\x1bReleaseRefTypeMismatchError\x10\x18\x12\x17\n\x13\x42rTypeMismatchError\x10\x19\x12\x1b\n\x17\x41ssertTypeMismatchError\x10\x1a\x12\x1a\n\x16StLocTypeMismatchError\x10\x1b\x12\x1d\n\x19StLocUnsafeToDestroyError\x10\x1c\x12\x1b\n\x17RetUnsafeToDestroyError\x10\x1d\x12\x18\n\x14RetTypeMismatchError\x10\x1e\x12\x1e\n\x1a\x46reezeRefTypeMismatchError\x10\x1f\x12%\n!FreezeRefExistsMutableBorrowError\x10 \x12 \n\x1c\x42orrowFieldTypeMismatchError\x10!\x12\x1c\n\x18\x42orrowFieldBadFieldError\x10\"\x12\'\n#BorrowFieldExistsMutableBorrowError\x10#\x12\x1b\n\x17\x43opyLocUnavailableError\x10$\x12\x18\n\x14\x43opyLocResourceError\x10%\x12\x1c\n\x18\x43opyLocExistsBorrowError\x10&\x12\x1b\n\x17MoveLocUnavailableError\x10\'\x12\x1c\n\x18MoveLocExistsBorrowError\x10(\x12\x1b\n\x17\x42orrowLocReferenceError\x10)\x12\x1d\n\x19\x42orrowLocUnavailableError\x10*\x12\x1e\n\x1a\x42orrowLocExistsBorrowError\x10+\x12\x19\n\x15\x43\x61llTypeMismatchError\x10,\x12%\n!CallBorrowedMutableReferenceError\x10-\x12\x19\n\x15PackTypeMismatchError\x10.\x12\x1b\n\x17UnpackTypeMismatchError\x10/\x12\x1c\n\x18ReadRefTypeMismatchError\x10\x30\x12\x18\n\x14ReadRefResourceError\x10\x31\x12#\n\x1fReadRefExistsMutableBorrowError\x10\x32\x12\x1d\n\x19WriteRefTypeMismatchError\x10\x33\x12\x19\n\x15WriteRefResourceError\x10\x34\x12\x1d\n\x19WriteRefExistsBorrowError\x10\x35\x12#\n\x1fWriteRefNoMutableReferenceError\x10\x36\x12\x1e\n\x1aIntegerOpTypeMismatchError\x10\x37\x12\x1e\n\x1a\x42ooleanOpTypeMismatchError\x10\x38\x12\x1f\n\x1b\x45qualityOpTypeMismatchError\x10\x39\x12#\n\x1f\x45xistsResourceTypeMismatchError\x10:\x12!\n\x1d\x42orrowGlobalTypeMismatchError\x10;\x12\x1f\n\x1b\x42orrowGlobalNoResourceError\x10<\x12\x1d\n\x19MoveFromTypeMismatchError\x10=\x12\x1b\n\x17MoveFromNoResourceError\x10>\x12!\n\x1dMoveToSenderTypeMismatchError\x10?\x12\x1f\n\x1bMoveToSenderNoResourceError\x10@\x12\"\n\x1e\x43reateAccountTypeMismatchError\x10\x41\x12#\n\x1fModuleAddressDoesNotMatchSender\x10\x42\x12\x13\n\x0fNoModuleHandles\x10\x43*\xe0\x01\n\x19VMInvariantViolationError\x12\"\n\x1eUnknownInvariantViolationError\x10\x00\x12\x14\n\x10OutOfBoundsIndex\x10\x01\x12\x14\n\x10OutOfBoundsRange\x10\x02\x12\x13\n\x0f\x45mptyValueStack\x10\x03\x12\x12\n\x0e\x45mptyCallStack\x10\x04\x12\x0e\n\nPCOverflow\x10\x05\x12\x0f\n\x0bLinkerError\x10\x06\x12\x17\n\x13LocalReferenceError\x10\x07\x12\x10\n\x0cStorageError\x10\x08*\xf9\x01\n\x0b\x42inaryError\x12\x16\n\x12UnknownBinaryError\x10\x00\x12\r\n\tMalformed\x10\x01\x12\x0c\n\x08\x42\x61\x64Magic\x10\x02\x12\x12\n\x0eUnknownVersion\x10\x03\x12\x14\n\x10UnknownTableType\x10\x04\x12\x18\n\x14UnknownSignatureType\x10\x05\x12\x19\n\x15UnknownSerializedType\x10\x06\x12\x11\n\rUnknownOpcode\x10\x07\x12\x12\n\x0e\x42\x61\x64HeaderTable\x10\x08\x12\x1b\n\x17UnexpectedSignatureType\x10\t\x12\x12\n\x0e\x44uplicateTable\x10\n*\x86\x03\n\rRuntimeStatus\x12\x18\n\x14UnknownRuntimeStatus\x10\x00\x12\x0c\n\x08\x45xecuted\x10\x01\x12\x0c\n\x08OutOfGas\x10\x02\x12\x18\n\x14ResourceDoesNotExist\x10\x03\x12\x19\n\x15ResourceAlreadyExists\x10\x04\x12\x18\n\x14\x45victedAccountAccess\x10\x05\x12\x1f\n\x1b\x41\x63\x63ountAddressAlreadyExists\x10\x06\x12\r\n\tTypeError\x10\x07\x12\x0f\n\x0bMissingData\x10\x08\x12\x13\n\x0f\x44\x61taFormatError\x10\t\x12\x0f\n\x0bInvalidData\x10\n\x12\x13\n\x0fRemoteDataError\x10\x0b\x12\x1f\n\x1b\x43\x61nnotWriteExistingResource\x10\x0c\x12\x1b\n\x17ValueSerializationError\x10\r\x12\x1d\n\x19ValueDeserializationError\x10\x0e\x12\x17\n\x13\x44uplicateModuleName\x10\x0f\x62\x06proto3')
)

_VMVALIDATIONSTATUSCODE = _descriptor.EnumDescriptor(
  name='VMValidationStatusCode',
  full_name='types.VMValidationStatusCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UnknownValidationStatus', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidSignature', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidAuthKey', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SequenceNumberTooOld', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SequenceNumberTooNew', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InsufficientBalanceForTransactionFee', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TransactionExpired', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SendingAccountDoesNotExist', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RejectedWriteSet', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidWriteSet', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExceededMaxTransactionSize', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnknownScript', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnknownModule', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MaxGasUnitsExceedsMaxGasUnitsBound', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MaxGasUnitsBelowMinTransactionGasUnits', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GasUnitPriceBelowMinBound', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GasUnitPriceAboveMaxBound', index=16, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1451,
  serialized_end=1955,
)
_sym_db.RegisterEnumDescriptor(_VMVALIDATIONSTATUSCODE)

VMValidationStatusCode = enum_type_wrapper.EnumTypeWrapper(_VMVALIDATIONSTATUSCODE)
_VMVERIFICATIONERRORKIND = _descriptor.EnumDescriptor(
  name='VMVerificationErrorKind',
  full_name='types.VMVerificationErrorKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UnknownVerificationError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IndexOutOfBounds', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RangeOutOfBounds', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidSignatureToken', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidFieldDefReference', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RecursiveStructDefinition', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidResourceField', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidFallThrough', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JoinFailure', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NegativeStackSizeWithinBlock', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnbalancedStack', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidMainFunctionSignature', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DuplicateElement', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidModuleHandle', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnimplementedHandle', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InconsistentFields', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnusedFields', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LookupFailed', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VisibilityMismatch', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TypeResolutionFailure', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TypeMismatch', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MissingDependency', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PopReferenceError', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PopResourceError', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ReleaseRefTypeMismatchError', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BrTypeMismatchError', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AssertTypeMismatchError', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StLocTypeMismatchError', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StLocUnsafeToDestroyError', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RetUnsafeToDestroyError', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RetTypeMismatchError', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FreezeRefTypeMismatchError', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FreezeRefExistsMutableBorrowError', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BorrowFieldTypeMismatchError', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BorrowFieldBadFieldError', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BorrowFieldExistsMutableBorrowError', index=35, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CopyLocUnavailableError', index=36, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CopyLocResourceError', index=37, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CopyLocExistsBorrowError', index=38, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MoveLocUnavailableError', index=39, number=39,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MoveLocExistsBorrowError', index=40, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BorrowLocReferenceError', index=41, number=41,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BorrowLocUnavailableError', index=42, number=42,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BorrowLocExistsBorrowError', index=43, number=43,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CallTypeMismatchError', index=44, number=44,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CallBorrowedMutableReferenceError', index=45, number=45,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PackTypeMismatchError', index=46, number=46,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnpackTypeMismatchError', index=47, number=47,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ReadRefTypeMismatchError', index=48, number=48,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ReadRefResourceError', index=49, number=49,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ReadRefExistsMutableBorrowError', index=50, number=50,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WriteRefTypeMismatchError', index=51, number=51,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WriteRefResourceError', index=52, number=52,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WriteRefExistsBorrowError', index=53, number=53,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WriteRefNoMutableReferenceError', index=54, number=54,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IntegerOpTypeMismatchError', index=55, number=55,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BooleanOpTypeMismatchError', index=56, number=56,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EqualityOpTypeMismatchError', index=57, number=57,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExistsResourceTypeMismatchError', index=58, number=58,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BorrowGlobalTypeMismatchError', index=59, number=59,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BorrowGlobalNoResourceError', index=60, number=60,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MoveFromTypeMismatchError', index=61, number=61,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MoveFromNoResourceError', index=62, number=62,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MoveToSenderTypeMismatchError', index=63, number=63,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MoveToSenderNoResourceError', index=64, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CreateAccountTypeMismatchError', index=65, number=65,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ModuleAddressDoesNotMatchSender', index=66, number=66,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NoModuleHandles', index=67, number=67,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1958,
  serialized_end=3948,
)
_sym_db.RegisterEnumDescriptor(_VMVERIFICATIONERRORKIND)

VMVerificationErrorKind = enum_type_wrapper.EnumTypeWrapper(_VMVERIFICATIONERRORKIND)
_VMINVARIANTVIOLATIONERROR = _descriptor.EnumDescriptor(
  name='VMInvariantViolationError',
  full_name='types.VMInvariantViolationError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UnknownInvariantViolationError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OutOfBoundsIndex', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OutOfBoundsRange', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EmptyValueStack', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EmptyCallStack', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PCOverflow', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LinkerError', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LocalReferenceError', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StorageError', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3951,
  serialized_end=4175,
)
_sym_db.RegisterEnumDescriptor(_VMINVARIANTVIOLATIONERROR)

VMInvariantViolationError = enum_type_wrapper.EnumTypeWrapper(_VMINVARIANTVIOLATIONERROR)
_BINARYERROR = _descriptor.EnumDescriptor(
  name='BinaryError',
  full_name='types.BinaryError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UnknownBinaryError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Malformed', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BadMagic', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnknownVersion', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnknownTableType', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnknownSignatureType', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnknownSerializedType', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnknownOpcode', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BadHeaderTable', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnexpectedSignatureType', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DuplicateTable', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4178,
  serialized_end=4427,
)
_sym_db.RegisterEnumDescriptor(_BINARYERROR)

BinaryError = enum_type_wrapper.EnumTypeWrapper(_BINARYERROR)
_RUNTIMESTATUS = _descriptor.EnumDescriptor(
  name='RuntimeStatus',
  full_name='types.RuntimeStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UnknownRuntimeStatus', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Executed', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OutOfGas', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResourceDoesNotExist', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResourceAlreadyExists', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EvictedAccountAccess', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AccountAddressAlreadyExists', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TypeError', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MissingData', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DataFormatError', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidData', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RemoteDataError', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CannotWriteExistingResource', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueSerializationError', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueDeserializationError', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DuplicateModuleName', index=15, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4430,
  serialized_end=4820,
)
_sym_db.RegisterEnumDescriptor(_RUNTIMESTATUS)

RuntimeStatus = enum_type_wrapper.EnumTypeWrapper(_RUNTIMESTATUS)
UnknownValidationStatus = 0
InvalidSignature = 1
InvalidAuthKey = 2
SequenceNumberTooOld = 3
SequenceNumberTooNew = 4
InsufficientBalanceForTransactionFee = 5
TransactionExpired = 6
SendingAccountDoesNotExist = 7
RejectedWriteSet = 8
InvalidWriteSet = 9
ExceededMaxTransactionSize = 10
UnknownScript = 11
UnknownModule = 12
MaxGasUnitsExceedsMaxGasUnitsBound = 13
MaxGasUnitsBelowMinTransactionGasUnits = 14
GasUnitPriceBelowMinBound = 15
GasUnitPriceAboveMaxBound = 16
UnknownVerificationError = 0
IndexOutOfBounds = 1
RangeOutOfBounds = 2
InvalidSignatureToken = 3
InvalidFieldDefReference = 4
RecursiveStructDefinition = 5
InvalidResourceField = 6
InvalidFallThrough = 7
JoinFailure = 8
NegativeStackSizeWithinBlock = 9
UnbalancedStack = 10
InvalidMainFunctionSignature = 11
DuplicateElement = 12
InvalidModuleHandle = 13
UnimplementedHandle = 14
InconsistentFields = 15
UnusedFields = 16
LookupFailed = 17
VisibilityMismatch = 18
TypeResolutionFailure = 19
TypeMismatch = 20
MissingDependency = 21
PopReferenceError = 22
PopResourceError = 23
ReleaseRefTypeMismatchError = 24
BrTypeMismatchError = 25
AssertTypeMismatchError = 26
StLocTypeMismatchError = 27
StLocUnsafeToDestroyError = 28
RetUnsafeToDestroyError = 29
RetTypeMismatchError = 30
FreezeRefTypeMismatchError = 31
FreezeRefExistsMutableBorrowError = 32
BorrowFieldTypeMismatchError = 33
BorrowFieldBadFieldError = 34
BorrowFieldExistsMutableBorrowError = 35
CopyLocUnavailableError = 36
CopyLocResourceError = 37
CopyLocExistsBorrowError = 38
MoveLocUnavailableError = 39
MoveLocExistsBorrowError = 40
BorrowLocReferenceError = 41
BorrowLocUnavailableError = 42
BorrowLocExistsBorrowError = 43
CallTypeMismatchError = 44
CallBorrowedMutableReferenceError = 45
PackTypeMismatchError = 46
UnpackTypeMismatchError = 47
ReadRefTypeMismatchError = 48
ReadRefResourceError = 49
ReadRefExistsMutableBorrowError = 50
WriteRefTypeMismatchError = 51
WriteRefResourceError = 52
WriteRefExistsBorrowError = 53
WriteRefNoMutableReferenceError = 54
IntegerOpTypeMismatchError = 55
BooleanOpTypeMismatchError = 56
EqualityOpTypeMismatchError = 57
ExistsResourceTypeMismatchError = 58
BorrowGlobalTypeMismatchError = 59
BorrowGlobalNoResourceError = 60
MoveFromTypeMismatchError = 61
MoveFromNoResourceError = 62
MoveToSenderTypeMismatchError = 63
MoveToSenderNoResourceError = 64
CreateAccountTypeMismatchError = 65
ModuleAddressDoesNotMatchSender = 66
NoModuleHandles = 67
UnknownInvariantViolationError = 0
OutOfBoundsIndex = 1
OutOfBoundsRange = 2
EmptyValueStack = 3
EmptyCallStack = 4
PCOverflow = 5
LinkerError = 6
LocalReferenceError = 7
StorageError = 8
UnknownBinaryError = 0
Malformed = 1
BadMagic = 2
UnknownVersion = 3
UnknownTableType = 4
UnknownSignatureType = 5
UnknownSerializedType = 6
UnknownOpcode = 7
BadHeaderTable = 8
UnexpectedSignatureType = 9
DuplicateTable = 10
UnknownRuntimeStatus = 0
Executed = 1
OutOfGas = 2
ResourceDoesNotExist = 3
ResourceAlreadyExists = 4
EvictedAccountAccess = 5
AccountAddressAlreadyExists = 6
TypeError = 7
MissingData = 8
DataFormatError = 9
InvalidData = 10
RemoteDataError = 11
CannotWriteExistingResource = 12
ValueSerializationError = 13
ValueDeserializationError = 14
DuplicateModuleName = 15


_VMVERIFICATIONSTATUS_STATUSKIND = _descriptor.EnumDescriptor(
  name='StatusKind',
  full_name='types.VMVerificationStatus.StatusKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCRIPT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODULE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=363,
  serialized_end=399,
)
_sym_db.RegisterEnumDescriptor(_VMVERIFICATIONSTATUS_STATUSKIND)

_ARITHMETICERROR_ARITHMETICERRORTYPE = _descriptor.EnumDescriptor(
  name='ArithmeticErrorType',
  full_name='types.ArithmeticError.ArithmeticErrorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UnknownArithmeticError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Underflow', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Overflow', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DivisionByZero', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=535,
  serialized_end=633,
)
_sym_db.RegisterEnumDescriptor(_ARITHMETICERROR_ARITHMETICERRORTYPE)

_DYNAMICREFERENCEERROR_DYNAMICREFERENCEERRORTYPE = _descriptor.EnumDescriptor(
  name='DynamicReferenceErrorType',
  full_name='types.DynamicReferenceError.DynamicReferenceErrorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UnknownDynamicReferenceError', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MoveOfBorrowedResource', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GlobalRefAlreadyReleased', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MissingReleaseRef', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GlobalAlreadyBorrowed', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=738,
  serialized_end=907,
)
_sym_db.RegisterEnumDescriptor(_DYNAMICREFERENCEERROR_DYNAMICREFERENCEERRORTYPE)


_VMVALIDATIONSTATUS = _descriptor.Descriptor(
  name='VMValidationStatus',
  full_name='types.VMValidationStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='types.VMValidationStatus.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='types.VMValidationStatus.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=108,
)


_VMVERIFICATIONSTATUSLIST = _descriptor.Descriptor(
  name='VMVerificationStatusList',
  full_name='types.VMVerificationStatusList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_list', full_name='types.VMVerificationStatusList.status_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=186,
)


_VMVERIFICATIONSTATUS = _descriptor.Descriptor(
  name='VMVerificationStatus',
  full_name='types.VMVerificationStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_kind', full_name='types.VMVerificationStatus.status_kind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='module_idx', full_name='types.VMVerificationStatus.module_idx', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_kind', full_name='types.VMVerificationStatus.error_kind', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='types.VMVerificationStatus.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VMVERIFICATIONSTATUS_STATUSKIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=399,
)


_ASSERTIONFAILURE = _descriptor.Descriptor(
  name='AssertionFailure',
  full_name='types.AssertionFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='assertion_error_code', full_name='types.AssertionFailure.assertion_error_code', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=449,
)


_ARITHMETICERROR = _descriptor.Descriptor(
  name='ArithmeticError',
  full_name='types.ArithmeticError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_code', full_name='types.ArithmeticError.error_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ARITHMETICERROR_ARITHMETICERRORTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=452,
  serialized_end=633,
)


_DYNAMICREFERENCEERROR = _descriptor.Descriptor(
  name='DynamicReferenceError',
  full_name='types.DynamicReferenceError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_code', full_name='types.DynamicReferenceError.error_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DYNAMICREFERENCEERROR_DYNAMICREFERENCEERRORTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=907,
)


_EXECUTIONSTATUS = _descriptor.Descriptor(
  name='ExecutionStatus',
  full_name='types.ExecutionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime_status', full_name='types.ExecutionStatus.runtime_status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assertion_failure', full_name='types.ExecutionStatus.assertion_failure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arithmetic_error', full_name='types.ExecutionStatus.arithmetic_error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_error', full_name='types.ExecutionStatus.reference_error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='execution_status', full_name='types.ExecutionStatus.execution_status',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=910,
  serialized_end=1158,
)


_VMSTATUS = _descriptor.Descriptor(
  name='VMStatus',
  full_name='types.VMStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validation', full_name='types.VMStatus.validation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verification', full_name='types.VMStatus.verification', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invariant_violation', full_name='types.VMStatus.invariant_violation', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deserialization', full_name='types.VMStatus.deserialization', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='execution', full_name='types.VMStatus.execution', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='error_type', full_name='types.VMStatus.error_type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1161,
  serialized_end=1448,
)

_VMVALIDATIONSTATUS.fields_by_name['code'].enum_type = _VMVALIDATIONSTATUSCODE
_VMVERIFICATIONSTATUSLIST.fields_by_name['status_list'].message_type = _VMVERIFICATIONSTATUS
_VMVERIFICATIONSTATUS.fields_by_name['status_kind'].enum_type = _VMVERIFICATIONSTATUS_STATUSKIND
_VMVERIFICATIONSTATUS.fields_by_name['error_kind'].enum_type = _VMVERIFICATIONERRORKIND
_VMVERIFICATIONSTATUS_STATUSKIND.containing_type = _VMVERIFICATIONSTATUS
_ARITHMETICERROR.fields_by_name['error_code'].enum_type = _ARITHMETICERROR_ARITHMETICERRORTYPE
_ARITHMETICERROR_ARITHMETICERRORTYPE.containing_type = _ARITHMETICERROR
_DYNAMICREFERENCEERROR.fields_by_name['error_code'].enum_type = _DYNAMICREFERENCEERROR_DYNAMICREFERENCEERRORTYPE
_DYNAMICREFERENCEERROR_DYNAMICREFERENCEERRORTYPE.containing_type = _DYNAMICREFERENCEERROR
_EXECUTIONSTATUS.fields_by_name['runtime_status'].enum_type = _RUNTIMESTATUS
_EXECUTIONSTATUS.fields_by_name['assertion_failure'].message_type = _ASSERTIONFAILURE
_EXECUTIONSTATUS.fields_by_name['arithmetic_error'].message_type = _ARITHMETICERROR
_EXECUTIONSTATUS.fields_by_name['reference_error'].message_type = _DYNAMICREFERENCEERROR
_EXECUTIONSTATUS.oneofs_by_name['execution_status'].fields.append(
  _EXECUTIONSTATUS.fields_by_name['runtime_status'])
_EXECUTIONSTATUS.fields_by_name['runtime_status'].containing_oneof = _EXECUTIONSTATUS.oneofs_by_name['execution_status']
_EXECUTIONSTATUS.oneofs_by_name['execution_status'].fields.append(
  _EXECUTIONSTATUS.fields_by_name['assertion_failure'])
_EXECUTIONSTATUS.fields_by_name['assertion_failure'].containing_oneof = _EXECUTIONSTATUS.oneofs_by_name['execution_status']
_EXECUTIONSTATUS.oneofs_by_name['execution_status'].fields.append(
  _EXECUTIONSTATUS.fields_by_name['arithmetic_error'])
_EXECUTIONSTATUS.fields_by_name['arithmetic_error'].containing_oneof = _EXECUTIONSTATUS.oneofs_by_name['execution_status']
_EXECUTIONSTATUS.oneofs_by_name['execution_status'].fields.append(
  _EXECUTIONSTATUS.fields_by_name['reference_error'])
_EXECUTIONSTATUS.fields_by_name['reference_error'].containing_oneof = _EXECUTIONSTATUS.oneofs_by_name['execution_status']
_VMSTATUS.fields_by_name['validation'].message_type = _VMVALIDATIONSTATUS
_VMSTATUS.fields_by_name['verification'].message_type = _VMVERIFICATIONSTATUSLIST
_VMSTATUS.fields_by_name['invariant_violation'].enum_type = _VMINVARIANTVIOLATIONERROR
_VMSTATUS.fields_by_name['deserialization'].enum_type = _BINARYERROR
_VMSTATUS.fields_by_name['execution'].message_type = _EXECUTIONSTATUS
_VMSTATUS.oneofs_by_name['error_type'].fields.append(
  _VMSTATUS.fields_by_name['validation'])
_VMSTATUS.fields_by_name['validation'].containing_oneof = _VMSTATUS.oneofs_by_name['error_type']
_VMSTATUS.oneofs_by_name['error_type'].fields.append(
  _VMSTATUS.fields_by_name['verification'])
_VMSTATUS.fields_by_name['verification'].containing_oneof = _VMSTATUS.oneofs_by_name['error_type']
_VMSTATUS.oneofs_by_name['error_type'].fields.append(
  _VMSTATUS.fields_by_name['invariant_violation'])
_VMSTATUS.fields_by_name['invariant_violation'].containing_oneof = _VMSTATUS.oneofs_by_name['error_type']
_VMSTATUS.oneofs_by_name['error_type'].fields.append(
  _VMSTATUS.fields_by_name['deserialization'])
_VMSTATUS.fields_by_name['deserialization'].containing_oneof = _VMSTATUS.oneofs_by_name['error_type']
_VMSTATUS.oneofs_by_name['error_type'].fields.append(
  _VMSTATUS.fields_by_name['execution'])
_VMSTATUS.fields_by_name['execution'].containing_oneof = _VMSTATUS.oneofs_by_name['error_type']
DESCRIPTOR.message_types_by_name['VMValidationStatus'] = _VMVALIDATIONSTATUS
DESCRIPTOR.message_types_by_name['VMVerificationStatusList'] = _VMVERIFICATIONSTATUSLIST
DESCRIPTOR.message_types_by_name['VMVerificationStatus'] = _VMVERIFICATIONSTATUS
DESCRIPTOR.message_types_by_name['AssertionFailure'] = _ASSERTIONFAILURE
DESCRIPTOR.message_types_by_name['ArithmeticError'] = _ARITHMETICERROR
DESCRIPTOR.message_types_by_name['DynamicReferenceError'] = _DYNAMICREFERENCEERROR
DESCRIPTOR.message_types_by_name['ExecutionStatus'] = _EXECUTIONSTATUS
DESCRIPTOR.message_types_by_name['VMStatus'] = _VMSTATUS
DESCRIPTOR.enum_types_by_name['VMValidationStatusCode'] = _VMVALIDATIONSTATUSCODE
DESCRIPTOR.enum_types_by_name['VMVerificationErrorKind'] = _VMVERIFICATIONERRORKIND
DESCRIPTOR.enum_types_by_name['VMInvariantViolationError'] = _VMINVARIANTVIOLATIONERROR
DESCRIPTOR.enum_types_by_name['BinaryError'] = _BINARYERROR
DESCRIPTOR.enum_types_by_name['RuntimeStatus'] = _RUNTIMESTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VMValidationStatus = _reflection.GeneratedProtocolMessageType('VMValidationStatus', (_message.Message,), dict(
  DESCRIPTOR = _VMVALIDATIONSTATUS,
  __module__ = 'vm_errors_pb2'
  # @@protoc_insertion_point(class_scope:types.VMValidationStatus)
  ))
_sym_db.RegisterMessage(VMValidationStatus)

VMVerificationStatusList = _reflection.GeneratedProtocolMessageType('VMVerificationStatusList', (_message.Message,), dict(
  DESCRIPTOR = _VMVERIFICATIONSTATUSLIST,
  __module__ = 'vm_errors_pb2'
  # @@protoc_insertion_point(class_scope:types.VMVerificationStatusList)
  ))
_sym_db.RegisterMessage(VMVerificationStatusList)

VMVerificationStatus = _reflection.GeneratedProtocolMessageType('VMVerificationStatus', (_message.Message,), dict(
  DESCRIPTOR = _VMVERIFICATIONSTATUS,
  __module__ = 'vm_errors_pb2'
  # @@protoc_insertion_point(class_scope:types.VMVerificationStatus)
  ))
_sym_db.RegisterMessage(VMVerificationStatus)

AssertionFailure = _reflection.GeneratedProtocolMessageType('AssertionFailure', (_message.Message,), dict(
  DESCRIPTOR = _ASSERTIONFAILURE,
  __module__ = 'vm_errors_pb2'
  # @@protoc_insertion_point(class_scope:types.AssertionFailure)
  ))
_sym_db.RegisterMessage(AssertionFailure)

ArithmeticError = _reflection.GeneratedProtocolMessageType('ArithmeticError', (_message.Message,), dict(
  DESCRIPTOR = _ARITHMETICERROR,
  __module__ = 'vm_errors_pb2'
  # @@protoc_insertion_point(class_scope:types.ArithmeticError)
  ))
_sym_db.RegisterMessage(ArithmeticError)

DynamicReferenceError = _reflection.GeneratedProtocolMessageType('DynamicReferenceError', (_message.Message,), dict(
  DESCRIPTOR = _DYNAMICREFERENCEERROR,
  __module__ = 'vm_errors_pb2'
  # @@protoc_insertion_point(class_scope:types.DynamicReferenceError)
  ))
_sym_db.RegisterMessage(DynamicReferenceError)

ExecutionStatus = _reflection.GeneratedProtocolMessageType('ExecutionStatus', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONSTATUS,
  __module__ = 'vm_errors_pb2'
  # @@protoc_insertion_point(class_scope:types.ExecutionStatus)
  ))
_sym_db.RegisterMessage(ExecutionStatus)

VMStatus = _reflection.GeneratedProtocolMessageType('VMStatus', (_message.Message,), dict(
  DESCRIPTOR = _VMSTATUS,
  __module__ = 'vm_errors_pb2'
  # @@protoc_insertion_point(class_scope:types.VMStatus)
  ))
_sym_db.RegisterMessage(VMStatus)


# @@protoc_insertion_point(module_scope)
